/*
 * Copyright (C) 2000 John David Ratliff, Jason Andrew Fisk, and Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package controller;

import javax.swing.JTextField;

import controller.MVC_Controller;
import controller.HistoryListener;
import controller.TextFieldListener;

import datatypes.Stack;
import datastructures.DynamicHistoryStack;

import model.MVC_Model;

/* The Controller class implements the control mechanisms that the user will be using.
	We also did the extra credit command history list here using the up (previous)
	and down (retraversal) stacks to store the commands. There is a method in
	TextFieldListener to see if a given input is a command
*/

public class Controller implements MVC_Controller {
	private MVC_Model model;
	private Stack upStack;
	private Stack downStack;

	private final static int HISTORY_MAX = 10;

	// initilize the Controller and set the view
	public Controller(MVC_Model model) {
		this.model = model;

		// the stacks are used to keep track of the command history forwards (up) and back (down)
		this.upStack = new DynamicHistoryStack(Controller.HISTORY_MAX);
		this.downStack = new DynamicHistoryStack(Controller.HISTORY_MAX);
	}

	public void handleTextFieldEvents(JTextField textField) {
		// add the necessary listeners to the textField (KeyListener and ActionListener)

		textField.addActionListener(new TextFieldListener(
			this.model, this.upStack, this.downStack, textField));
		textField.addKeyListener(new HistoryListener(
			this.upStack, this.downStack, textField));
	}
}
