/*
 * Copyright (C) 2000 John David Ratliff, Jason Andrew Fisk, and Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package controller;

import java.awt.event.KeyListener;
import java.awt.event.KeyEvent;
import javax.swing.JTextField;

import datatypes.Stack;

public class HistoryListener implements KeyListener {
	private JTextField textField;
	private Stack upStack;
	private Stack downStack;

	// initilize the HistoryListener
	public HistoryListener(Stack upStack, Stack downStack, JTextField textField) {
		this.textField = textField;
		this.upStack = upStack;
		this.downStack = downStack;
	}

	public void keyPressed(KeyEvent event) {
		String command;
		int keyCode = event.getKeyCode();

		if (keyCode == KeyEvent.VK_UP) {
			command = (String)this.upStack.pop();

			if (command != null) {
				// restore the previous command and save it for the return
				this.downStack.push(command);

				if (command.equals(this.textField.getText())) {
					// if we pressed down then up, the command we want
					// is one more down
					command = (String)this.upStack.pop();

					if (command != null) {
						this.downStack.push(command);
					}
				}

				if (command != null) {
					this.textField.setText(command);
				}
			}
		} else if (keyCode == KeyEvent.VK_DOWN) {
			command = (String)downStack.pop();

			if (command == null) {
				if (this.textField.getText().equals((String)this.upStack.peek())) {
					// if this is the last command on the history stack
					// then remove the command
					this.textField.setText("");
				}
			} else {
				this.upStack.push(command);

				if (command.equals(this.textField.getText())) {
					// if we pressed up then down, the command we want
					// is one more up
					command = (String)this.downStack.pop();

					if (command != null) {
						this.upStack.push(command);
					}
				}

				if (command == null) {
					// if the possibly new command is null, then erase the command
					this.textField.setText("");
				} else {
					// otherwise, restore the command
					this.textField.setText(command);
				}
			}
		}
	}

	public void keyReleased(KeyEvent event) {
		// ignore KEY_RELEASED events
	}

	public void keyTyped(KeyEvent event) {
		// ignore KEY_TYPED events
	}
}