/*
 * Copyright (C) 2000 John David Ratliff, Jason Andrew Fisk, and Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package datastructures;

import datatypes.Stack;
import datastructures.DoublyLinkedList;

/* A Stack (or semi-deque as it is) which is Bounded, but Dynamically removes the bottom
	when it gets too big (past the bounds) and keeps going. There is no limit to how
	big the Stack can be, but when it grows beyond the boundaries, the boundaries are lost
*/

public class DynamicHistoryStack implements Stack {
	private DoublyLinkedList list;
	private int maximumElements;

	// initilize the Stack
	public DynamicHistoryStack(int maximumElements) {
		this.list = new DoublyLinkedList();
		this.maximumElements = maximumElements;
	}

	// push an element onto the stack
	public void push(Object element) {
		if (this.isFull()) {
			// full means we're at capacity, we need to delete the bottom to add more
			// to the top
			this.list.delete(0);
		}

		this.list.insert(this.list.size(), element);
	}

	// pop an element from the top of the stack
	public Object pop() {
		if (this.isEmpty()) {
			// nothing to pop
			return null;
		}

		// make sure delete returns an element :-)
		return this.list.delete(this.list.size()-1);
	}

	// examine the element from the top of the stack without 'popping' it
	public Object peek() {
		if (this.isEmpty()) {
			// nothing to peek at
			return null;
		}

		return this.list.get(this.list.size()-1);
	}

	// returns the size of the stack
	public int size() {
		return this.list.size();
	}

	// returns whether the stack is full or not, i.e. at the boundaries
	public boolean isFull() {
		return (this.list.size() >= maximumElements);
	}

	// returns whether the stack is empty or not
	public boolean isEmpty() {
		return (this.list.size() == 0);
	}
}
