/*
 * Copyright (C) 2000 John David Ratliff, Jason Andrew Fisk, and Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package model;

import datastructures.DoublyLinkedList;
import datatypes.List;

//////////////////////////////////////////////////////////////////////
/**
 * This class represents a list of Line objects.  It only supports
 * operations performed on Line objects, and no others.
 */
//////////////////////////////////////////////////////////////////////
public class LineList
    {
    private List list;

    //////////////////////////////////////////////////////////////////////
    /**
     * Create an empty list holding no lines.
     **/
    public LineList()
        {
	list = new DoublyLinkedList();
        }

    //////////////////////////////////////////////////////////////////////
    /**
     * Create a line list wrapping the supplied list.
     **/
    public LineList(List list)
        {
        this.list = list;
        }

    //////////////////////////////////////////////////////////////////////
    /** 
     * Insert the given line at the given index.
     *
     * @exception java.lang.IndexOutOfBoundsException Thrown when the index is
     * out of range
     */
    public void insert(int index, Line line) throws IndexOutOfBoundsException
        {
        if (index < 0 || index > list.size())
            {
            throw new IndexOutOfBoundsException();
            }
        else
            {
            list.insert(index, line);
            }
        }

    //////////////////////////////////////////////////////////////////////
    /** 
     * Delete the given Line.  Do nothing if the line is not present.
     *
     * @param line the line to delete.
     */
    public void delete(Line line)
        {
        int index = indexOf(line);
        list.delete(index);
        }

    //////////////////////////////////////////////////////////////////////
    /**
     * Return the size of this list.
     *
     * @return the size of this list.
     */
    public int size()
        {
	return list.size();
        }

    //////////////////////////////////////////////////////////////////////
    /**
     * Get a Line at the specified index.
     *
     * @exception java.lang.IndexOutOfBoundsException Thrown when the index is
     * either larger than the size of this list, or is negative.
     */
    public Line getLineAt(int index) throws IndexOutOfBoundsException
        {
	if(index < 0 || index >= size())
            {
	    throw new IndexOutOfBoundsException(index +" is out of range");
            }
	else
            {
	    return (Line)list.get(index);
            }
        }

    //////////////////////////////////////////////////////////////////////
    /**
     * Returns true if this LineList contains the given Line.
     *
     * @param line the line to find
     * @return true if the list contains line, false otherwise.
     */
    public boolean contains(Line line)
        {
	return (list.indexOf(line) != -1);
        }

    //////////////////////////////////////////////////////////////////////
    /**
     * Return the index of the given line.  Returns -1 if it is not in this
     * LineList.
     *
     * @param line the line to find the index of.
     **/
    public int indexOf(Line line)
        {
	return list.indexOf(line);
        }
    }
